pub enum RecordedLayerKind {
Regular,
Filter {
filter_data: FilterData,
placement: FilterLayerPlacement,
},
}Expand description
Additional metadata for regular and filter layers.
Variants
Regular
A regular layer.
Filter
A filter layer.
Fields

filter_data: FilterDataStatic data about the filter itself.

placement: FilterLayerPlacementData about how to place the filter layer, which can only be determined once its contents have been recorded.