CommandRecorder

Struct CommandRecorder 

pub struct CommandRecorder<D> {
    pub scene_size: SizeU16,
    pub nodes: Vec<Node>,
    pub draws: Vec<D>,
    pub layers: Vec<RecordedLayer>,
    pub filter_layers: Vec<u32>,
    pub root_is_blend_target: bool,
    pub max_layer_depth: usize,
    pub largest_layer_size: Option<SizeU16>,
    pub largest_filter_layer_size: Option<SizeU16>,
    pub has_non_default_blend: bool,
    active_layer: Option<u32>,
    layer_stack: Vec<OpenLayer>,
}
Recorder for a scene description.

Fields

scene_size: SizeU16

Tile-aligned dimensions of the root scene.

nodes: Vec<Node>

The nodes of the root layer.

draws: Vec<D>

Flat storage for all draw commands that are part of the recording.

layers: Vec<RecordedLayer>

Data about recorded layers, indexed by their ID.

filter_layers: Vec<u32>

IDs of recorded filter layers in creation order.

root_is_blend_target: bool

Whether the root is the target of a non-default blending operation.

max_layer_depth: usize

Maximum layer depth across the whole layer graph.

largest_layer_size: Option<SizeU16>

The largest dimensions of any recorded layer.

largest_filter_layer_size: Option<SizeU16>

The largest dimensions of any recorded filter layer.

has_non_default_blend: bool

Whether there exists at least one layer that uses a non-default blend mode.

active_layer: Option<u32>

The layer whose command stream is currently the base.

This is None if there is no active layer and we are recording into the root layer instead.

layer_stack: Vec<OpenLayer>

Stack of currently pushed layers.

Implementations

Source

impl<D> CommandRecorder<D>

pub fn new(width: u16, height: u16) -> Self

Create a new command recorder.

pub fn has_layers(&self) -> bool

Whether any layers are currently open.

pub fn reset(&mut self, width: u16, height: u16)

Reset the command recorder.

pub fn push_layer(&mut self, props: LayerProps, filter_plan: Option<FilterData>)

Push a new layer.

fn push_regular_layer(&mut self, props: LayerProps)

fn push_filter_layer(&mut self, props: LayerProps, filter_plan: FilterData)

fn push_recorded_layer(&mut self, layer: RecordedLayer) -> u32

pub fn pop_layer(&mut self) -> PoppedLayer

Pop the currently active layer.

fn active_node_mut(&mut self) -> Option<&mut Node>

fn push_node(&mut self, node: Node)

fn push_layer_node(&mut self, layer_id: u32)

fn push_layer_metadata(&mut self, layer: RecordedLayer) -> u32

fn record_bbox(&mut self, bbox: impl FnOnce() -> Option<RectU16>)

Source

impl<D: Drawable> CommandRecorder<D>

pub fn push_draw(&mut self, draw: D, strips: &[Strip])

Push a draw command.