pub struct RecordedLayer {
pub props: LayerProps,
pub nodes: SmallVec<[Node; 2]>,
pub kind: RecordedLayerKind,
pub depth: usize,
pub bbox: RectU16,
}Expand description
Metadata and child nodes for a recorded layer.
Fields
props: LayerPropsProperties of the layer.
nodes: SmallVec<[Node; 2]>The child nodes of the layer.
kind: RecordedLayerKindThe kind of recorded layer.
depth: usizeNesting depth of the layer.
bbox: RectU16Tile-aligned bounding box of the layer.
IMPORTANT: This field only indicates the bounding box of visible contents directly in this layer. It does not mean that any child layer is also strictly contained within those bounds.
For example:
Root surface
└── L0 — regular layer, clipped to 50 × 50
└── L1 — filter layer with a 100 × 100 bboxThis is a completely valid constellation. L1 needs to be rendered at its full resolution, but since the parent layer has a clip path, we can constrain it’s visible region. However, the child layer must remain unaffected by this.
Implementations
Sourceimpl RecordedLayer
impl RecordedLayer
fn regular(props: LayerProps, depth: usize) -> Self
fn filter(props: LayerProps, filter_plan: FilterData, depth: usize) -> Self