pub trait Drawable { // Required method fn bbox(&self, strips: &[Strip]) -> Option<RectU16>; }
A drawable object that can report its bounding box.
Return the tile-aligned bounding box of the given object, if it has one.